[cairo-commit] cairo/src cairo-font.c, 1.54, 1.55 cairo-ft-font.c, 1.76, 1.77 cairo-glitz-surface.c, 1.51, 1.52 cairo-pdf-surface.c, 1.52, 1.53 cairoint.h, 1.168, 1.169

Carl Worth commit at pdx.freedesktop.org
Mon Jul 25 16:23:07 PDT 2005


Committed by: cworth

Update of /cvs/cairo/cairo/src
In directory gabe:/tmp/cvs-serv26916/src

Modified Files:
	cairo-font.c cairo-ft-font.c cairo-glitz-surface.c 
	cairo-pdf-surface.c cairoint.h 
Log Message:

        * src/cairoint.h:
        * src/cairo-font.c:
        * src/cairo-ft-font.c:
        * src/cairo-glitz-surface.c:
        * src/cairo-pdf-surface.c: Replace all occurences of refcount with
        ref_count.

        * doc/public/language-bindings.xml: Replace refcounted with
        reference-counted.


Index: cairo-font.c
===================================================================
RCS file: /cvs/cairo/cairo/src/cairo-font.c,v
retrieving revision 1.54
retrieving revision 1.55
diff -u -d -r1.54 -r1.55
--- cairo-font.c	21 Jul 2005 13:52:13 -0000	1.54
+++ cairo-font.c	25 Jul 2005 23:23:05 -0000	1.55
@@ -45,7 +45,7 @@
 _cairo_font_face_init (cairo_font_face_t               *font_face, 
 		       const cairo_font_face_backend_t *backend)
 {
-    font_face->refcount = 1;
+    font_face->ref_count = 1;
     font_face->backend = backend;
 
     _cairo_user_data_array_init (&font_face->user_data);
@@ -66,7 +66,7 @@
     if (font_face == NULL)
 	return;
 
-    font_face->refcount++;
+    font_face->ref_count++;
 }
 
 /**
@@ -83,7 +83,7 @@
     if (font_face == NULL)
 	return;
 
-    if (--(font_face->refcount) > 0)
+    if (--(font_face->ref_count) > 0)
 	return;
 
     font_face->backend->destroy (font_face);
@@ -92,7 +92,7 @@
      * FreeType backend where cairo_ft_font_face_t and cairo_ft_unscaled_font_t
      * need to effectively mutually reference each other
      */
-    if (font_face->refcount > 0)
+    if (font_face->ref_count > 0)
 	return;
 
     _cairo_user_data_array_fini (&font_face->user_data);
@@ -774,7 +774,7 @@
     scaled_font->ctm = *ctm;
     cairo_matrix_multiply (&scaled_font->scale, &scaled_font->font_matrix, &scaled_font->ctm);
     
-    scaled_font->refcount = 1;
+    scaled_font->ref_count = 1;
     scaled_font->backend = backend;
 }
 
@@ -867,7 +867,7 @@
 _cairo_unscaled_font_init (cairo_unscaled_font_t               *unscaled_font, 
 			   const cairo_unscaled_font_backend_t *backend)
 {
-    unscaled_font->refcount = 1;
+    unscaled_font->ref_count = 1;
     unscaled_font->backend = backend;
 }
 
@@ -877,7 +877,7 @@
     if (unscaled_font == NULL)
 	return;
 
-    unscaled_font->refcount++;
+    unscaled_font->ref_count++;
 }
 
 void
@@ -886,7 +886,7 @@
     if (unscaled_font == NULL)
 	return;
 
-    if (--(unscaled_font->refcount) > 0)
+    if (--(unscaled_font->ref_count) > 0)
 	return;
 
     unscaled_font->backend->destroy (unscaled_font);
@@ -913,7 +913,7 @@
     if (scaled_font == NULL)
 	return;
 
-    scaled_font->refcount++;
+    scaled_font->ref_count++;
 }
 
 /**
@@ -933,7 +933,7 @@
     if (scaled_font == NULL)
 	return;
 
-    if (--(scaled_font->refcount) > 0)
+    if (--(scaled_font->ref_count) > 0)
 	return;
 
     if (scaled_font->font_face) {

Index: cairo-glitz-surface.c
===================================================================
RCS file: /cvs/cairo/cairo/src/cairo-glitz-surface.c,v
retrieving revision 1.51
retrieving revision 1.52
diff -u -d -r1.51 -r1.52
--- cairo-glitz-surface.c	21 Jul 2005 15:50:21 -0000	1.51
+++ cairo-glitz-surface.c	25 Jul 2005 23:23:05 -0000	1.52
@@ -1548,7 +1548,7 @@
 
 typedef struct {
     cairo_glyph_cache_key_t key;
-    int			    refcount;
+    int			    ref_count;
     cairo_glyph_size_t	    size;
     cairo_glitz_area_t	    *area;
     cairo_bool_t	    locked;
@@ -1606,7 +1606,7 @@
     if (!entry)
 	return CAIRO_STATUS_NO_MEMORY;
 
-    entry->refcount = 1;
+    entry->ref_count = 1;
     entry->key	    = *key;
     entry->area     = NULL;
     entry->locked   = FALSE;
@@ -1624,8 +1624,8 @@
 {
     cairo_glitz_glyph_cache_entry_t *entry = abstract_entry;
 
-    entry->refcount--;
-    if (entry->refcount)
+    entry->ref_count--;
+    if (entry->ref_count)
 	return;
 
     if (entry->area)
@@ -1641,7 +1641,7 @@
 {
     cairo_glitz_glyph_cache_entry_t *entry = abstract_entry;
 
-    entry->refcount++;	
+    entry->ref_count++;	
 }
 
 static void 

Index: cairo-pdf-surface.c
===================================================================
RCS file: /cvs/cairo/cairo/src/cairo-pdf-surface.c,v
retrieving revision 1.52
retrieving revision 1.53
diff -u -d -r1.52 -r1.53
--- cairo-pdf-surface.c	21 Jul 2005 13:52:13 -0000	1.52
+++ cairo-pdf-surface.c	25 Jul 2005 23:23:05 -0000	1.53
@@ -109,7 +109,7 @@
 
 struct cairo_pdf_document {
     cairo_output_stream_t *output_stream;
-    unsigned long refcount;
+    unsigned long ref_count;
     cairo_surface_t *owner;
     cairo_bool_t finished;
 
@@ -1422,7 +1422,7 @@
 	return NULL;
 
     document->output_stream = output_stream;
-    document->refcount = 1;
+    document->ref_count = 1;
     document->owner = NULL;
     document->finished = FALSE;
     document->width = width;
@@ -1653,14 +1653,14 @@
 static void
 _cairo_pdf_document_reference (cairo_pdf_document_t *document)
 {
-    document->refcount++;
+    document->ref_count++;
 }
 
 static void
 _cairo_pdf_document_destroy (cairo_pdf_document_t *document)
 {
-    document->refcount--;
-    if (document->refcount > 0)
+    document->ref_count--;
+    if (document->ref_count > 0)
       return;
 
     _cairo_pdf_document_finish (document);

Index: cairoint.h
===================================================================
RCS file: /cvs/cairo/cairo/src/cairoint.h,v
retrieving revision 1.168
retrieving revision 1.169
diff -u -d -r1.168 -r1.169
--- cairoint.h	25 Jul 2005 19:29:24 -0000	1.168
+++ cairoint.h	25 Jul 2005 23:23:05 -0000	1.169
@@ -453,12 +453,12 @@
  * glyph cache.
  */
 struct _cairo_unscaled_font {
-    int refcount;
+    int ref_count;
     const cairo_unscaled_font_backend_t *backend;
 };
 
 struct _cairo_scaled_font {
-    int refcount;
+    int ref_count;
     cairo_matrix_t font_matrix;	  /* font space => user space */
     cairo_matrix_t ctm;	          /* user space => device space */
     cairo_matrix_t scale;	  /* font space => device space */
@@ -467,7 +467,7 @@
 };
 
 struct _cairo_font_face {
-    int refcount;
+    int ref_count;
     cairo_user_data_array_t user_data;
     const cairo_font_face_backend_t *backend;
 };




More information about the cairo-commit mailing list
Index: cairo-ft-font.c
===================================================================
RCS file: /cvs/cairo/cairo/src/cairo-ft-font.c,v
retrieving revision 1.76
retrieving revision 1.77
diff -u -d -r1.76 -r1.77
--- cairo-ft-font.c	24 Jul 2005 12:18:16 -0000	1.76
+++ cairo-ft-font.c	25 Jul 2005 23:23:05 -0000	1.77
@@ -2040,7 +2040,7 @@
 
     if (font_face->unscaled &&
 	font_face->unscaled->from_face &&
-	font_face->unscaled->base.refcount > 1) {
+	font_face->unscaled->base.ref_count > 1) {
 	cairo_font_face_reference (&font_face->base);
 	
 	_cairo_unscaled_font_destroy (&font_face->unscaled->base);
@@ -2270,7 +2270,7 @@
 /**
  * cairo_ft_font_face_create_for_ft_face:
  * @face: A FreeType face object, already opened. This must
  *   be kept around until the face's refcount drops to
  *   zero and it is freed. Since the face may be referenced
  *   internally to Cairo, the best way to determine when it
  *   is safe to free the face is to pass a
@@ -2270,7 +2270,7 @@
  * cairo_ft_font_face_create_for_ft_face:
  * @face: A FreeType face object, already opened. This must
- *   be kept around until the face's refcount drops to
+ *   be kept around until the face's ref_count drops to
  *   zero and it is freed. Since the face may be referenced
  *   internally to Cairo, the best way to determine when it
